<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Middleware;

use App\Repositories\Enums\ResponseCodeEnum;
use Closure;
use Illuminate\Auth\Access\AuthorizationException;
use Illuminate\Contracts\Auth\Factory as Auth;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Symfony\Component\HttpKernel\Exception\UnauthorizedHttpException;
use App\Support\Traits\Helpers;

class Authenticate
{
    use Helpers;
    /**
     * The authentication guard factory instance.
     *
     * @var Auth
     */
    protected $auth;

    /**
     * Create a new middleware instance.
     *
     * @param  Auth  $auth
     */
    public function __construct(Auth $auth)
    {
        $this->auth = $auth;
    }

    /**
     * Handle an incoming request.
     *
     * @param  Request  $request
     * @param  Closure  $next
     * @param  string|null  $guard
     * @return mixed
     *
     * @throws AuthorizationException
     */
    public function handle($request, Closure $next, $guard = null)
    {

        /**
         * 如果路由是登出或者是修改密码的时候，需要对token进行处理，否则jwt处理时会出错
         */ 
        if(Str::endsWith(strtolower((string) $request->getPathInfo()), 'logout') ||
            Str::endsWith(strtolower((string) $request->getPathInfo()), 'resetpassword')
            ){

            $token = trim(str_ireplace('bearer', '', $request->header('authorization')));
            $decodeToken = $this->decodeToken($token);
            if(empty($decodeToken) || (!is_array($decodeToken) && !$decodeToken['hash'])){
                throw new UnauthorizedHttpException('JWTAuth', 'Unable to authenticate with invalid token.');
            }

            /*$chains = app('tymon.jwt.parser')->getChain();
            $chains[0]->setHeaderName($decodeToken['hash']);
            app('tymon.jwt.parser')->setChain($chains);*/

            $request->headers->set('authorization','bearer'.$decodeToken['hash']);
        }

        return $next($request);
    }
}
